<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Penerima mengedit Form");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Penerima mengedit Form");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Form Halaman");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Anda dapat menetapkan lebih dari satu penerima dengan memisahkan email dengan koma.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Menyimpan penerima ...");
define('VIEW_FORM_TABLES_HEADING', "Lihat Tabel Formulir");
define('VIEW_FORM_TABLES_BTN', "Lihat Tabel Formulir");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Pilih Tabel untuk Lihat");
define('VIEW_FORM_TABLES_FILTER_READ', "Filter Baca Pesan");
?>